@@ -493,10 +493,19 @@ const unicodePropertyEscapeFixtures = [
 			'Extended_Pictographic'
 		]
 	},
+	{
+		'path': 'Script_Extensions/Yezidi',
+		'expressions': [
+			'scx=Yezi',
+			'scx=Yezidi',
+			'Script_Extensions=Yezi',
+			'Script_Extensions=Yezidi',
+		]
+	},
 ];
 
 const getPropertyValuePattern = (path) => {
-	const codePoints = require(`unicode-12.1.0/${
+	const codePoints = require(`unicode-13.0.0/${
 		path }/code-points.js`);
 	return {
 		'p': regenerate(codePoints).toString(),
@@ -583,14 +592,6 @@ describe('unicodePropertyEscapes', () => {
 			rewritePattern('\\P{ASCII_Hex_Digit}', '', features);
 		}, Error);
 	});
-	it('throws without the `unicodePropertyEscape` feature enabled', () => {
-		assert.throws(() => {
-			rewritePattern('\\p{ASCII_Hex_Digit}', 'u');
-		}, Error);
-		assert.throws(() => {
-			rewritePattern('\\P{ASCII_Hex_Digit}', 'u');
-		}, Error);
-	});
 	it('throws on unknown binary properties', () => {
 		assert.throws(() => {
 			rewritePattern('\\p{UnknownBinaryProperty}', 'u', features);
@@ -689,6 +690,12 @@ describe('unicodePropertyEscapes', () => {
 			'[\\u{14400}-\\u{14646}]'
 		);
 	});
+	it('should not transpile unicode property when unicodePropertyEscape is not enabled', () => {
+		assert.equal(
+			rewritePattern('\\p{ASCII_Hex_Digit}\\P{ASCII_Hex_Digit}', 'u'),
+			'\\p{ASCII_Hex_Digit}\\P{ASCII_Hex_Digit}'
+		);
+	});
 	assert.equal(
 		rewritePattern('\u03B8', 'iu'),
 		'[\\u03B8\\u03F4]'
@@ -829,7 +836,6 @@ describe('namedGroup', () => {
 
 	it('onNamedGroup is optional', () => {
 		let transpiled;
-		const pattern = '(?<name>)';
 		const expected = '()';
 		assert.doesNotThrow(() => {
 			transpiled = rewritePattern('(?<name>)', '', {
@@ -854,6 +860,15 @@ describe('namedGroup', () => {
 			});
 		});
 	});
+
+	it('should not transpile when namedGroup is not enabled', () => {
+		let transpiled;
+		const expected = '(?<name>)';
+		assert.doesNotThrow(() => {
+			transpiled = rewritePattern('(?<name>)', '');
+		});
+		assert.strictEqual(expected, transpiled);
+	})
 });
 
 const lookbehindFixtures = [
